import logging
import glob
from hardware_interfaces.base_io.base_io_interface import BaseIOInterface


class DeviceFileIO(BaseIOInterface):
    logger = logging.getLogger(__name__)

    def __init__(self, base_dir='/sys/bus/w1/devices/', device_file_name='/w1_slave', *args, **kwargs):
        self.base_dir = base_dir
        self.device_folder = glob.glob(base_dir + '28*')[0]
        self.device_file = self.device_folder + device_file_name

        super(DeviceFileIO, self).__init__(*args, **kwargs)










import logging
from pyhap.const import CATEGORY_SENSOR
from OpenHub.homekit_accessories.homkit_sensor_interface import HomeKitSensorInterface


class HumiditySensor(HomeKitSensorInterface):
    logger = logging.getLogger(__name__)
    run_debug_message = "Current Relative Humidity Level: "


    index = None
    channel = None
    air_temp_hum_service = None
    air_temp_hum_service2 = None
    char_temp = None
    char_hum = None
    category = CATEGORY_SENSOR
    serial_no = None
    name = None
    display_name = None

    def __init__(self, serial_no=None, display_name=None, channel_interface_serial_no=None, *args, **kwargs):
        self.from_json(kwargs["data"])
        super().__init__(serial_no=serial_no, display_name=display_name,
                         channel_interface_serial_no=channel_interface_serial_no, *args, **kwargs)

    def set_display_name(self, display_name):
        if self.display_name is None:
            return display_name + "Humidity"

    def as_json(self):
        sensor_dict = {"aid": self.aid, "serial_no": self.serial_no,

                       "display_name": self.display_name}
        return sensor_dict

    def from_json(self, data):
        if "serial_no" in data.keys():
            self.serial_no = data["serial_no"]
        if "index" in data.keys():
            self.index = data["index"]
        if "name" in data.keys():
            self.name = data["name"]
        if "aid" in data.keys():
            self.aid = data["aid"]
        if "display_name" in data.keys():
            self.display_name = data["display_name"]

    def add_info_service(self):

        serv_info = self.driver.loader.get_service("AccessoryInformation")
        serv_info.configure_char("Name", value=self.display_name)
        serv_info.configure_char("SerialNumber", value=self.serial_no)
        serv_info.configure_char("Manufacturer", value="BellyFrito")
        serv_info.configure_char("Model", value="AirTempAndHumiditySensor")
        self.add_service(serv_info)

    def add_functional_service(self):
        return self.add_preload_service("HumiditySensor")

    def add_functional_service_characteristic(self):
        return self.service.get_characteristic('CurrentRelativeHumidity')
    #
    # async def run(self):
    #     temperature_f = dhti.get_temp_c()
    #     humidity = dhti.get_humidity()
    #     if temperature_f is not None:
    #         self.char_temp.set_value(temperature_f)
    #     if humidity is not None:
    #         self.char_hum.set_value(humidity)
    #     self.logger.debug("Current Air Temp(F): " + str(temperature_f))
    #     self.logger.debug("Current Humidity: " + str(humidity))



import logging

from hardware_interfaces.base_io.base_io_interface import BaseIOInterface


class PiPicoGPI(BaseIOInterface):
    logger = logging.getLogger(__name__)

    def __init__(self, pin=1, *args, **kwargs):
        self.pin = pin
        super(PiPicoGPI, self).__init__(*args, **kwargs)



from .hardware import first_time_setup
from .homekit_interfaces import first_time_kit_setup
from OpenHub.globals import id_hardware_map


def first_run():
    first_time_kit_setup.first_run()
    first_time_setup.first_run()
    for component in id_hardware_map:
        interface_channel_with_homekit_accessory(component)


import board
import busio
import adafruit_veml7700
from .hardware_interface import HardwareInterface
from .channels.veml7700_light import VEML7700Light
from .channels.veml7700_lux import VEML7700Lux


class VEML7700(HardwareInterface):

    def __init__(self, scl=board.SCL, sda=board.SDA, serial_no=None, channels=None, *args, **kwargs):
        self.i2c = busio.I2C(scl, sda)
        self.veml7700 = adafruit_veml7700.VEML7700(self.i2c)
        self.type = self.__name__
        super().__init__(serial_no, channels, *args, **kwargs)

    def create_channel(self):
        return {"light": VEML7700Light(veml=self.veml7700, hardware_serial_no=self.serial_no),
                "lux": VEML7700Lux(veml=self.veml7700, hardware_serial_no=self.serial_no)}



from .channel_interface import ChannelInterface
import time
import logging


class DHT22Temp(ChannelInterface):
    logger = logging.getLogger(__name__)

    def __init__(self, hardware_serial_no=None, serial_no=None, dht_device=None, *args,
                 **kwargs):
        self.type = self.__name__
        self.dhtDevice = dht_device
        super().__init__(hardware_serial_no=hardware_serial_no, serial_no=serial_no, *args, **kwargs)

    def get_raw_data(self):
        try:
            return float(self.dhtDevice.temperature)
        except RuntimeError as error:
            # Errors happen fairly often, DHT's are hard to read, just keep going
            logger.info(error.args[0])
            time.sleep(2.0)
            self.get_raw_data()
        except Exception as error:
            self.dhtDevice.exit()
            logger.error("DHT Device is down", error)



from .channel_interface import ChannelInterface
import logging


class VEML7700Lux(ChannelInterface):
    logger = logging.getLogger(__name__)

    def __init__(self, veml=None, hardware_serial_no=None, serial_no=None, *args, **kwargs):
        self.veml = veml
        self.type = self.__name__
        super().__init__(hardware_serial_no=hardware_serial_no, serial_no=serial_no, *args, **kwargs)

    def get_raw_data(self):
        return self.veml.veml7700.lux
